summaryrefslogtreecommitdiff
path: root/l10ntools/inc
diff options
context:
space:
mode:
authorCarsten Driesner <cd@openoffice.org>2011-01-12 16:14:41 +0100
committerCarsten Driesner <cd@openoffice.org>2011-01-12 16:14:41 +0100
commita0602756a7bd259f6ee4e62161afe00298ba1d6c (patch)
tree8b1fdc48610d073122e449f46a42736acb3c9652 /l10ntools/inc
parent0f029bd13462f28ae38bd1371c7c7b42dd992bdc (diff)
removetooltypes01: #i112600# Exchange misleading sal_uIntPtr with sal_uLong in l10ntools
Diffstat (limited to 'l10ntools/inc')
-rw-r--r--l10ntools/inc/cfgmerge.hxx6
-rw-r--r--l10ntools/inc/export.hxx10
-rw-r--r--l10ntools/inc/gsicheck.hxx12
-rw-r--r--l10ntools/inc/tagtest.hxx14
-rw-r--r--l10ntools/inc/xmlparse.hxx4
5 files changed, 23 insertions, 23 deletions
diff --git a/l10ntools/inc/cfgmerge.hxx b/l10ntools/inc/cfgmerge.hxx
index e0c2c0cf61f2..2f6418e1aa3f 100644
--- a/l10ntools/inc/cfgmerge.hxx
+++ b/l10ntools/inc/cfgmerge.hxx
@@ -76,13 +76,13 @@ public:
CfgStack() : CfgStackList( 10, 10 ) {}
~CfgStack();
- sal_uIntPtr Push( CfgStackData *pStackData );
+ sal_uLong Push( CfgStackData *pStackData );
CfgStackData *Push( const ByteString &rTag, const ByteString &rId );
CfgStackData *Pop() { return Remove( Count() - 1 ); }
- CfgStackData *GetStackData( sal_uIntPtr nPos = LIST_APPEND );
+ CfgStackData *GetStackData( sal_uLong nPos = LIST_APPEND );
- ByteString GetAccessPath( sal_uIntPtr nPos = LIST_APPEND );
+ ByteString GetAccessPath( sal_uLong nPos = LIST_APPEND );
};
//
diff --git a/l10ntools/inc/export.hxx b/l10ntools/inc/export.hxx
index 768e63b03fd8..b315d6cb3040 100644
--- a/l10ntools/inc/export.hxx
+++ b/l10ntools/inc/export.hxx
@@ -114,11 +114,11 @@ DECLARE_LIST( ExportListBase, ExportListEntry * )
class ExportList : public ExportListBase
{
private:
- sal_uIntPtr nSourceLanguageListEntryCount;
+ sal_uLong nSourceLanguageListEntryCount;
public:
ExportList() : ExportListBase() { nSourceLanguageListEntryCount = 0; }
- sal_uIntPtr GetSourceLanguageListEntryCount() { return nSourceLanguageListEntryCount; }
+ sal_uLong GetSourceLanguageListEntryCount() { return nSourceLanguageListEntryCount; }
void NewSourceLanguageListEntry() { nSourceLanguageListEntryCount++; }
};
@@ -302,11 +302,11 @@ private:
sal_Bool bDefine; // cur. res. in a define?
sal_Bool bNextMustBeDefineEOL; // define but no \ at lineend
- sal_uIntPtr nLevel; // res. recursiv? how deep?
+ sal_uLong nLevel; // res. recursiv? how deep?
sal_uInt16 nList; // cur. res. is String- or FilterList
ByteString nListLang;
- sal_uIntPtr nListIndex;
- sal_uIntPtr nListLevel;
+ sal_uLong nListIndex;
+ sal_uLong nListLevel;
bool bSkipFile;
ByteString sProject;
ByteString sRoot;
diff --git a/l10ntools/inc/gsicheck.hxx b/l10ntools/inc/gsicheck.hxx
index 49a1f861eed0..6779557a4bb6 100644
--- a/l10ntools/inc/gsicheck.hxx
+++ b/l10ntools/inc/gsicheck.hxx
@@ -41,7 +41,7 @@ private:
ParserMessageList aMessages;
LineFormat aFormat;
- sal_uIntPtr nLineNumber;
+ sal_uLong nLineNumber;
ByteString aUniqId;
ByteString aLineType;
@@ -56,9 +56,9 @@ private:
void ReassembleLine();
public:
- GSILine( const ByteString &rLine, sal_uIntPtr nLine );
+ GSILine( const ByteString &rLine, sal_uLong nLine );
LineFormat GetLineFormat() const { return aFormat; }
- sal_uIntPtr GetLineNumber() const { return nLineNumber; }
+ sal_uLong GetLineNumber() const { return nLineNumber; }
ByteString const GetUniqId() const { return aUniqId; }
ByteString const GetLineType() const { return aLineType; }
@@ -113,11 +113,11 @@ private:
public:
GSIBlock( sal_Bool PbPrintContext, sal_Bool bSource, sal_Bool bTrans, sal_Bool bRef, sal_Bool bAllowKID, sal_Bool bAllowSusp );
~GSIBlock();
- void PrintMessage( ByteString aType, ByteString aMsg, ByteString aPrefix, ByteString aContext, sal_uIntPtr nLine, ByteString aUniqueId = ByteString() );
- void PrintError( ByteString aMsg, ByteString aPrefix, ByteString aContext, sal_uIntPtr nLine, ByteString aUniqueId = ByteString() );
+ void PrintMessage( ByteString aType, ByteString aMsg, ByteString aPrefix, ByteString aContext, sal_uLong nLine, ByteString aUniqueId = ByteString() );
+ void PrintError( ByteString aMsg, ByteString aPrefix, ByteString aContext, sal_uLong nLine, ByteString aUniqueId = ByteString() );
void InsertLine( GSILine* pLine, const ByteString aSourceLang);
void SetReferenceLine( GSILine* pLine );
- sal_Bool CheckSyntax( sal_uIntPtr nLine, sal_Bool bRequireSourceLine, sal_Bool bFixTags );
+ sal_Bool CheckSyntax( sal_uLong nLine, sal_Bool bRequireSourceLine, sal_Bool bFixTags );
void WriteError( LazySvFileStream &aErrOut, sal_Bool bRequireSourceLine );
void WriteCorrect( LazySvFileStream &aOkOut, sal_Bool bRequireSourceLine );
diff --git a/l10ntools/inc/xmlparse.hxx b/l10ntools/inc/xmlparse.hxx
index cb72ca532afe..5be58ffb50a7 100644
--- a/l10ntools/inc/xmlparse.hxx
+++ b/l10ntools/inc/xmlparse.hxx
@@ -490,8 +490,8 @@ public:
*/
struct XMLError {
XML_Error eCode; // the error code
- sal_uIntPtr nLine; // error line number
- sal_uIntPtr nColumn; // error column number
+ sal_uLong nLine; // error line number
+ sal_uLong nColumn; // error column number
String sMessage; // readable error message
};
diff --git a/l10ntools/inc/tagtest.hxx b/l10ntools/inc/tagtest.hxx
index 90b19037e6e9..ef2a696d71d7 100644
--- a/l10ntools/inc/tagtest.hxx
+++ b/l10ntools/inc/tagtest.hxx
@@ -235,13 +235,13 @@ public:
void Clear()
{
- for ( sal_uIntPtr i = 0 ; i < Count() ; i++ )
+ for ( sal_uLong i = 0 ; i < Count() ; i++ )
delete TokenListImpl::GetObject( i );
TokenListImpl::Clear();
}
- void Insert( TokenInfo p, sal_uIntPtr nIndex = LIST_APPEND )
+ void Insert( TokenInfo p, sal_uLong nIndex = LIST_APPEND )
{ TokenListImpl::Insert( new TokenInfo(p), nIndex ); }
-/* TokenInfo Remove( sal_uIntPtr nIndex )
+/* TokenInfo Remove( sal_uLong nIndex )
{
TokenInfo aT = GetObject( nIndex );
delete TokenListImpl::GetObject( nIndex );
@@ -250,16 +250,16 @@ public:
}*/
// TokenInfo Remove( TokenInfo p ){ return Remove( GetPos( p ) ); }
// TokenInfo GetCurObject() const { return *TokenListImpl::GetCurObject(); }
- TokenInfo& GetObject( sal_uIntPtr nIndex ) const
+ TokenInfo& GetObject( sal_uLong nIndex ) const
{
// if ( TokenListImpl::GetObject(nIndex) )
return *TokenListImpl::GetObject(nIndex);
// else
// return TokenInfo();
}
/* sal_uIntPtr GetPos( const TokenInfo p ) const
{
- for ( sal_uIntPtr i = 0 ; i < Count() ; i++ )
+ for ( sal_uLong i = 0 ; i < Count() ; i++ )
if ( p == GetObject( i ) )
return i;
return LIST_ENTRY_NOTFOUND;
@@ -267,7 +267,7 @@ public:
TokenList( const TokenList& rList );
/* {
- for ( sal_uIntPtr i = 0 ; i < rList.Count() ; i++ )
+ for ( sal_uLong i = 0 ; i < rList.Count() ; i++ )
{
Insert( rList.GetObject( i ), LIST_APPEND );
}
@@ -250,16 +250,16 @@ public:
// return TokenInfo();
}
-/* sal_uIntPtr GetPos( const TokenInfo p ) const
+/* sal_uLong GetPos( const TokenInfo p ) const
{